* Recreate regression results from "Inequality and School Funding in the Rural U.S., 1890"
use "/users/dietz/dropbox/uscounty/stata/tax_final.dta", clear

local urblimit 0 // Set maximum urbanization rate for regressions

* Table 4 - Main results using Gini coefficients
xi: reg lschtaxpc i.state allfarmgini lntvalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit', cluster(state)
estimates store taxA

xi: reg lschtaxpc i.state allfarmgini_adj_mal lntvalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit', cluster(state)
estimates store taxB

xi: reg lschtaxpc i.state allfarmgini lntvalpc1000 lnavalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit', cluster(state)
estimates store taxC

xi: reg lschtaxpc i.state allfarmgini_adj_mal lntvalpc1000 lnavalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit', cluster(state)
estimates store taxD

xi: reg lschtaxpc i.state allfarmgini_adj_mal lntvalpc1000 lnavalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit' & south==0, cluster(state)
estimates store taxE

xi: reg lschtaxpc i.state allfarmgini_adj_mal lntvalpc1000 lnavalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit' & south==1, cluster(state)
estimates store taxF

xi: reg lschtaxpc i.state allfarmgini_adj_white_mal lntvalpc1000 lnavalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb<=`urblimit' & south==1, cluster(state)
estimates store taxG

* Write the raw TeX output for table 4 to output file
estout taxA taxB taxC taxD taxE taxF taxG using tax_table_4.txt, replace ///
	style(tex) /// write as a TeX file
	cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) /// each coefficient should get sig. stars, have 3 decimal places
	stats(r2 N N_clust, fmt(%9.3f %9.0f %9.0f) labels("R-squared" "Observations" "States")) /// extra information - R-squared, N, clusters
	keep( allfarmgini allfarmgini_adj_mal allfarmgini_adj_white_mal lntvalpc1000 lnavalpc1000 lnoutputpc percblack percchild lnpop ) ///
	order(allfarmgini allfarmgini_adj_mal allfarmgini_adj_white_mal lntvalpc1000 lnavalpc1000 lnoutputpc percblack percchild lnpop) /// 
	label mlabels(none) collabels(none) /// use variable labels, do not use model label or column labels (I do these myself)
	starlevels(* 0.10 ** 0.05 *** 0.01) /// set the sig stars level
	prefoot(\hline) /// put a horizontal line before the footer statistics
	varlabels(,elist(allfarmgini \addlinespace allfarmgini_adj_mal \addlinespace allfarmgini_adj_white_mal \addlinespace)) // stick extra space after variables

* Set up farm share variables for table 5
capture drop f049 f100_500 f1000
gen f049 = farmshare049
gen f100_500 = farmshare100_500
gen f1000 = farmshare1000
	
* Table 5
xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0, cluster(state)
estimates store taxA

xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000 lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0, cluster(state)
estimates store taxB

xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000 ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0, cluster(state)
estimates store taxC

xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000 ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==0, cluster(state)
estimates store taxD

xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000 ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxE

* Write the raw TeX output for table 5 to output file
estout taxA taxB taxC taxD taxE taxF taxG using \users\dietz\dropbox\uscounty\stata\tax_table_5.txt, replace ///
	style(tex) cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	stats(r2 N N_clust) keep( f049 f100_500 f1000 /// 
	lntvalpc1000 lnavalpc1000 lnoutputpc percblack percchild lnpop )  ///
	starlevels(* 0.10 ** 0.05 *** 0.01)

* Table 6
xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000 ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1 & lschtaxdummy==1, cluster(state)
estimates store taxA

xi: reg lschtaxdummy i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000  ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxB

xi: reg lschtaxdummy i.state f049 f100_500 f1000 sschtaxpc lntvalpc1000 lnavalpc1000  ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxC

* Generate total spending variable
capture drop allschexppc
gen allschexppc = lschtaxpc + sschtaxpc

xi: reg allschexppc i.state f049 f100_500 f1000  lntvalpc1000 lnavalpc1000 ln_farmsize  lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxD

* Set up owned farm shares
replace f049 = fashare049ow
replace f100_500 = fashare100_500ow
replace f1000 = fashare1000ow

xi: reg lschtaxpc i.state f049 f100_500 f1000 lntvalpc1000 lnavalpc1000  ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxE

xi: reg lschtaxpc i.state f049 f100_500 f1000 sschtaxpc lntvalpc1000 lnavalpc1000  ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxF

xi: reg lschtaxdummy i.state f049 f100_500 f1000 sschtaxpc lntvalpc1000 lnavalpc1000  ln_farmsize lnoutputpc /// 
	percblack percchild lnpop ///
	if percurb==0 & south==1, cluster(state)
estimates store taxG

* Write the raw TeX output for table 6 to output file
estout taxA taxB taxC taxD taxE taxF taxG using \users\dietz\dropbox\uscounty\stata\tax_table_6.txt, replace ///
	style(tex) cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	stats(r2 N N_clust) keep(f049 f100_500 f1000 sschtaxpc /// 
	lntvalpc1000 lnavalpc1000 ln_farmsize lnoutputpc percblack percchild lnpop )  ///
	starlevels(* 0.10 ** 0.05 *** 0.01)
